@@ -15,11 +15,16 @@ test_that("create Dockerfile with packages", {
 
 test_that("create Dockerfile with 'additional' packages", {
     skip_on_cran()
+    local_mocked_bindings(
+        version_name = function(metadata) "20120304T050607Z-xxxxx",
+        .package = "pins"
+    )
     v$metadata$required_pkgs <- c("pingr", "caret", "stats")
     vetiver_pin_write(b, v)
     vetiver_write_plumber(b, "cars1", file = file.path(tmp_dir, "plumber.R"))
     vetiver_write_docker(v, file.path(tmp_dir, "plumber.R"), tmp_dir,
                          additional_pkgs = c("caret", "ggplot2"))
+    expect_true(fs::file_exists(fs::path(tmp_dir, "vetiver_renv.lock")))
     expect_snapshot(
         cat(readr::read_lines(file.path(tmp_dir, "Dockerfile")), sep = "\n"),
         transform = redact_vetiver
@@ -28,6 +33,10 @@ test_that("create Dockerfile with 'additional' packages", {
 
 test_that("create Dockerfile with no RSPM", {
     skip_on_cran()
+    local_mocked_bindings(
+        version_name = function(metadata) "20120304T050607Z-yyyyy",
+        .package = "pins"
+    )
     v$metadata$required_pkgs <- c("pingr", "caret")
     vetiver_pin_write(b, v)
     vetiver_write_plumber(b, "cars1", file = file.path(tmp_dir, "plumber.R"))
